function [EST_SA1, EST_SA2, EST_A]=Est_AreaChange(EST_SL1, EST_SL2, EST_L)

% Cuts estuaries at the estuarine length. Computes the area in km2 of estuary 
% at time 1 and time 2 as well as area loss, gain and net change in km2 and percent. 
% For river channels, the longer channel mask is adjusted to the longer
% channel mask.
%
% INPUTS :
%           EST_SL1 - Matlab file containing output of Est_Length tool for
%           time 1 in raster format
%           EST_SL2 - Matlab file containing output of Est_Length tool for
%           time 2 in raster format
%           EST_L - Matlab file containing output of Est_Length tool for
%           estuarine length in table format
%
%
% OUTPUTS :
%           EST_SA1 - Matlab file containing information about area at time
%           1 in raster format
%           EST_SA2 - Matlab file containing information about area at time
%           2 in raster format
%           EST_A - Matlab file containing information about area, net area
%           change, gain and loss in table format

[n,~]=size(EST_SL2);

for i=1:n
%% Limitation
    disp('Limitation')

    try
    if ~isempty(EST_SL1(i).start_x) || ~isempty(EST_SL2(i).start_x)
        
    EST_SL1(i).RE_ind=EST_SL1(i).Rind==1 & EST_SL1(i).Length<EST_SL1(i).E_Length;
    EST_SL2(i).RE_ind=EST_SL2(i).Rind==1 & EST_SL2(i).Length<EST_SL2(i).E_Length;

    EST_SL1(i).RE_ind_fix=EST_SL1(i).Rind==1 & EST_SL1(i).Length<EST_SL1(i).E_Length_fix;
    EST_SL2(i).RE_ind_fix=EST_SL2(i).Rind==1 & EST_SL2(i).Length<EST_SL2(i).E_Length_fix;

    else
    end
    
    catch ME
        continue
    end

    clear a A1 A2 A11 ans b5 b6 frame t writerObj
    disp('Limitation : done')
    
%% Area
    disp('Area')

    % Urban = 100, water = 210, agriculture = 10, 20 and 30. Land reclamation = urban + agriculture. But I save agriculture and urban separately. And the rest is natural
    L.Lon=ncread('Landuse_degree.nc','lon');
    L.Lat=ncread('Landuse_degree.nc','lat');

    try
    if ~isempty(EST_SL1(i).start_x) || ~isempty(EST_SL2(i).start_x)
        One.ind1=find(EST_SL1(i).RE_ind);
        One.rad=sqrt((EST_SL1(i).cl(max(One.ind1),1)-EST_SL1(i).cl(min(One.ind1),1))^2+(EST_SL1(i).cl(max(One.ind1),2)-EST_SL1(i).cl(min(One.ind1),2))^2);
        [t1,t2]=size(EST_SL1(i).data);
        [t3,t4]=meshgrid([1:t2],[1:t1]);
        t3=t3-EST_SL1(i).point_x; t4=t4-EST_SL1(i).point_y;
        leng=sqrt(t3.^2+t4.^2);
        leng(leng>One.rad)=nan;
        One.A=double(isfinite(leng));
        One.A(EST_SL1(i).data==0)=0;
        
        Two.ind1=find(EST_SL2(i).RE_ind);
        Two.rad=sqrt((EST_SL2(i).cl(max(Two.ind1),1)-EST_SL2(i).cl(min(Two.ind1),1))^2+(EST_SL2(i).cl(max(Two.ind1),2)-EST_SL2(i).cl(min(Two.ind1),2))^2);
        [t1,t2]=size(EST_SL2(i).data);
        [t3,t4]=meshgrid([1:t2],[1:t1]);
        t3=t3-EST_SL2(i).point_x; t4=t4-EST_SL2(i).point_y;
        leng=sqrt(t3.^2+t4.^2);
        leng(leng>Two.rad)=nan;
        Two.A=double(isfinite(leng)); Two.A=Two.A*3;
        Two.A(EST_SL2(i).data==0)=0;
        
        l1=EST_SL1(i).point_x; l2=EST_SL2(i).point_x;
        r1=size(EST_SL1(i).data,2)-l1; r2=size(EST_SL2(i).data,2)-l2;
        u1=EST_SL1(i).point_y; u2=EST_SL2(i).point_y;
        d1=size(EST_SL1(i).data,1)-u1; d2=size(EST_SL2(i).data,1)-u2;
        
        lon=[EST_SL1(i).start_x_coor,EST_SL2(i).start_x_coor];
        lat=[EST_SL1(i).start_y_coor,EST_SL2(i).start_y_coor];
        [l,lt]=max([l1,l2]); r=max([r1,r2]); [u,ut]=max([u1,u2]); d=max([d1,d2]);
        lon=lon(lt); lat=lat(ut);
        Lon=lon+km2deg(EST_SL1(i).cell*([1:(l+r)]-l)/1000);
        Lat=lat+km2deg(EST_SL1(i).cell*(u-[1:(u+d)])/1000);
        
        F=nan*ones(u+d,l+r);
        Fl1=l2-l1+1; Fl1(Fl1<=0)=1; Fu1=u2-u1+1; Fu1(Fu1<=0)=1;
        Fl2=l1-l2+1; Fl2(Fl2<=0)=1; Fu2=u1-u2+1; Fu2(Fu2<=0)=1;
        
        F1=F; F2=F;
        F1(Fu1:Fu1+u1+d1-1,Fl1:Fl1+l1+r1-1)=One.A;
        F2(Fu2:Fu2+u2+d2-1,Fl2:Fl2+l2+r2-1)=Two.A;
        F=F1-F2;
        
        EST_L(i).Lon=Lon;
        EST_L(i).Lat=Lat;
        EST_L(i).F=F;
        EST_L(i).Area1=length(find(F==1 | F==-2))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Area2=length(find(F==-3 | F==-2))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Loss=length(find(F==1))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Gain=length(find(F==-3))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Net_change=(EST_L(i).Gain-EST_L(i).Loss);
        
        disp({i,'/',n})
        clear ans a1 a2 d d1 d2 F F1 F2 Fl1 Fl2 Fu1 Fu2 ind1 ind2 ind3 ind4 l l1 l2 Land lat Lat leng lon Lon lt m r r1 r2 t1 t2 t3 t4 u u1 u2 ut z One Two

    else
    end
    
    catch ME
        continue
    end
        
% fix
    try
    if ~isempty(EST_SL1(i).start_x) || ~isempty(EST_SL2(i).start_x)
        One.ind1=find(EST_SL1(i).RE_ind_fix);
        One.rad=sqrt((EST_SL1(i).cl(max(One.ind1),1)-EST_SL1(i).cl(min(One.ind1),1))^2+(EST_SL1(i).cl(max(One.ind1),2)-EST_SL1(i).cl(min(One.ind1),2))^2);
        [t1,t2]=size(EST_SL1(i).data);
        [t3,t4]=meshgrid([1:t2],[1:t1]);
        t3=t3-EST_SL1(i).point_x; t4=t4-EST_SL1(i).point_y;
        leng=sqrt(t3.^2+t4.^2);
        leng(leng>One.rad)=nan;
        One.A=double(isfinite(leng));
        One.A(EST_SL1(i).data==0)=0;
        
        Two.ind1=find(EST_SL2(i).RE_ind_fix);
        Two.rad=sqrt((EST_SL2(i).cl(max(Two.ind1),1)-EST_SL2(i).cl(min(Two.ind1),1))^2+(EST_SL2(i).cl(max(Two.ind1),2)-EST_SL2(i).cl(min(Two.ind1),2))^2);
        [t1,t2]=size(EST_SL2(i).data);
        [t3,t4]=meshgrid([1:t2],[1:t1]);
        t3=t3-EST_SL2(i).point_x; t4=t4-EST_SL2(i).point_y;
        leng=sqrt(t3.^2+t4.^2);
        leng(leng>Two.rad)=nan;
        Two.A=double(isfinite(leng)); Two.A=Two.A*3;
        Two.A(EST_SL2(i).data==0)=0;
        
        l1=EST_SL1(i).point_x; l2=EST_SL2(i).point_x;
        r1=size(EST_SL1(i).data,2)-l1; r2=size(EST_SL2(i).data,2)-l2;
        u1=EST_SL1(i).point_y; u2=EST_SL2(i).point_y;
        d1=size(EST_SL1(i).data,1)-u1; d2=size(EST_SL2(i).data,1)-u2;
        
        lon=[EST_SL1(i).start_x_coor,EST_SL2(i).start_x_coor];
        lat=[EST_SL1(i).start_y_coor,EST_SL2(i).start_y_coor];
        [l,lt]=max([l1,l2]); r=max([r1,r2]); [u,ut]=max([u1,u2]); d=max([d1,d2]);
        lon=lon(lt); lat=lat(ut);
        Lon=lon+km2deg(EST_SL1(i).cell*([1:(l+r)]-l)/1000);
        Lat=lat+km2deg(EST_SL1(i).cell*(u-[1:(u+d)])/1000);
        
        F=nan*ones(u+d,l+r);
        Fl1=l2-l1+1; Fl1(Fl1<=0)=1; Fu1=u2-u1+1; Fu1(Fu1<=0)=1;
        Fl2=l1-l2+1; Fl2(Fl2<=0)=1; Fu2=u1-u2+1; Fu2(Fu2<=0)=1;
        
        F1=F; F2=F;
        F1(Fu1:Fu1+u1+d1-1,Fl1:Fl1+l1+r1-1)=One.A;
        F2(Fu2:Fu2+u2+d2-1,Fl2:Fl2+l2+r2-1)=Two.A;
        F=F1-F2;
        
        EST_L(i).Lon_fix=Lon;
        EST_L(i).Lat_fix=Lat;
        EST_L(i).F_fix=F;
        EST_L(i).Area1_fix=length(find(F==1 | F==-2))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Area2_fix=length(find(F==-3 | F==-2))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Loss_fix=length(find(F==1))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Gain_fix=length(find(F==-3))*EST_SL1(i).cell*EST_SL1(i).cell/1000000;
        EST_L(i).Net_change_fix=(EST_L(i).Gain_fix-EST_L(i).Loss_fix);

        disp({i,'/',n})
        clear ans a1 a2 d d1 d2 F F1 F2 Fl1 Fl2 Fu1 Fu2 ind1 ind2 ind3 ind4 l l1 l2 Land lat Lat leng lon Lon lt m r r1 r2 t1 t2 t3 t4 u u1 u2 ut z One Two
        
    else
    end
    
    catch ME
        continue
    end
    
    disp('Area : done')
    
end

%% Save
    
    EST_SA1=EST_SL1;
    EST_SA2=EST_SL2;
    EST_A=EST_L;
    
    disp('Est_AreaChange : done')
    
end