function [EST_AL]=Est_AreaChange_Land(EST_SA1, EST_SA2, EST_A)

% Computes the area of estuarine surface area loss due to human-induced,
% natural and other factors. The function uses the global land-use dataset
% (downloadable at: http://maps.elie.ucl.ac.be/CCI/viewer/download.php).
% Reclaimed land is defined as land classified as urban and/or agriculture,
% while natural land represents land classified as forest, grassland, or
% baren land. Misclassification of estuarine surface area loss as water may
% arise, if th resolution of the land-use dataset and channel mask are
% different (= others). The dataset can be exchanged for a local, higher
% resolution land-use dataset.
% 
% INPUTS :
%           EST_SA1 - Matlab file containing output from Est_AreaChange
%           function for time 1 in raster format
%           EST_SA2 - Matlab file containing output from Est_AreaChange
%           function for time 2 in raster format
%           EST_A - Matlab file containing output from Est_AreaChange
%           function for area change in table format
%
%
% OUTPUTS :
%           EST_SAL1 - Matlab file containing information about land-use of
%           area change for time 1 in raster format
%           EST_SAL2 - Matlab file containing information about land-use of
%           area change for time 2 in raster format
%           EST_AL - Matlab file contianing information about the land-use
%           of area change in table format

[n,~]=size(EST_SA2);

for i=1:n
%% Area
    disp('Land use')

    % Urban = 190, water = 210, agriculture = 10, 20 and 30. Land reclamation = urban + agriculture. But I save agriculture and urban separately. And the rest is natural
    L.Lon=ncread('Landuse_degree.nc','lon');
    L.Lat=ncread('Landuse_degree.nc','lat');

    try
    if ~isempty(EST_SA1(i).start_x) || ~isempty(EST_SA2(i).start_x)
        
        F=EST_A(i).F;
        Lon=EST_A(i).Lon; Lat=EST_A(i).Lat;
        a1=min(Lon)-L.Lon; a1=find(abs(a1)==min(abs(a1)));
        a2=max(Lat)-L.Lat; a2=find(abs(a2)==min(abs(a2)));
        z=double(ncread('Landuse_degree.nc','ESACCI-LC-L4-LCCS-Map-300m-P5Y-2010-v1.6.1.tif',[a1,a2],[ceil(size(F,1)/10),ceil(size(F,2)/10)]));
        [ind1,ind2]=find(F==1);
        ind1=ceil(ind1/10); ind2=ceil(ind2/10);
        for m=1:length(ind1)
            Land(m)=z(ind1(m),ind2(m));
            if mod(m,1000)==1
                disp({'m',m})
            else
            end
        end
        
        exist Land
        if ans==0
            Land=nan;
        end
        
        ind1=Land==190;
        ind1=nansum(ind1);
        ind2=Land==10 | Land==20 | Land==30; 
        ind2=nansum(ind2);
        ind3=Land~=190 & Land~=210 & Land~=220 &  Land~=10 &  Land~=20 & Land~=30 & ~isnan(Land);
        ind3=nansum(ind3);
        
        EST_A(i).Loss_urban=ind1*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        EST_A(i).Loss_agriculture=ind2*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        EST_A(i).Loss_natural=ind3*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        
        clear ans a1 a2 d d1 d2 F F1 F2 Fl1 Fl2 Fu1 Fu2 ind1 ind2 ind3 ind4 l l1 l2 Land lat Lat leng lon Lon lt m r r1 r2 t1 t2 t3 t4 u u1 u2 ut z One Two

    else
    end
    
    catch ME
        continue
    end
        
% fix
    try
    if ~isempty(EST_SA1(i).start_x) || ~isempty(EST_SA2(i).start_x)
        
        Lon=EST_A(i).Lon_fix; Lat=EST_A(i).Lat_fix;
        F=EST_A(i).F_fix;
        a1=min(Lon)-L.Lon; a1=find(abs(a1)==min(abs(a1)));
        a2=max(Lat)-L.Lat; a2=find(abs(a2)==min(abs(a2)));
        z=double(ncread('Landuse_degree.nc','ESACCI-LC-L4-LCCS-Map-300m-P5Y-2010-v1.6.1.tif',[a1,a2],[ceil(size(F,1)/10),ceil(size(F,2)/10)]));
        [ind1,ind2]=find(F==1);
        ind1=ceil(ind1/10); ind2=ceil(ind2/10);
        for m=1:length(ind1)
            Land(m)=z(ind1(m),ind2(m));
            if mod(m,1000)==1
                disp({'m',m})
            else
            end
        end
        
        exist Land
        if ans==0
            Land=nan;
        end
        
        ind1=Land==190;
        ind1=nansum(ind1);
        ind2=Land==10 | Land==20 | Land==30; 
        ind2=nansum(ind2);
        ind3=Land~=190 & Land~=210 & Land~=220 &  Land~=10 &  Land~=20 & Land~=30 & ~isnan(Land);
        ind3=nansum(ind3);
        
        EST_A(i).Loss_urban_fix=ind1*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        EST_A(i).Loss_agriculture_fix=ind2*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        EST_A(i).Loss_natural_fix=ind3*EST_SA1(i).cell*EST_SA1(i).cell/1000000;
        
        clear ans a1 a2 d d1 d2 F F1 F2 Fl1 Fl2 Fu1 Fu2 ind1 ind2 ind3 ind4 l l1 l2 Land lat Lat leng lon Lon lt m r r1 r2 t1 t2 t3 t4 u u1 u2 ut z One Two

    else
    end
    
    catch ME
        continue
    end
    
    disp({i,'/',n})
    disp('Land use : done')

end

%% Save
    
    EST_AL=EST_A;
    
    disp('Est_AreaChange_Land : done')

end