function [EST_S]=Est_Shape(EST_W)

% Computes estuarine shape for one time step based on along-channel width
% and distance from the mouth (Davies and Woodroffe, 2010). Small shape
% values indicate a funnel shape and large values indicate straight
% channels
%
% INPUTS :
%           EST_W - Matlab file containing width outputs from
%           width_from_mask_MorphEst tool
%
%
% OUTPUTS :
%           EST_S - Matlab file containing shape information

[n,~]=size(EST_W);

for i=1:n
%% Shape
    disp('Shape')

    fo = fitoptions('Method','NonlinearLeastSquares','StartPoint',[2300,1400]);
    fun = fittype('W*exp(-(x/L))','options',fo);

    try
    if ~isempty(EST_W(i).start_x)
    a1=EST_W(i).Length(EST_W(i).Rind);
    a2=EST_W(i).Wbl(EST_W(i).Rind);
    ind=~isnan(a1) & ~isnan(a2);
    a3=a1(ind);
    a4=a2(ind);
    [f,g,~]=fit(a3,a4,fun);
    EST_W(i).f_W=f.W;
    EST_W(i).f_L=f.L;
    
    p=abs(f.W*exp(-(a3/f.L))-a3)./a3;
    EST_W(i).f_rsquare=g.rsquare;
    EST_W(i).f_lambda=prctile(p,75);
    
    EST_W(i).S=EST_W(i).f_L/EST_W(i).f_W;
    
    else
    end
    
    catch ME
        continue
    end

    clear a1 a2 a3 a4 f g h p fo fun 

    disp('Shape :done')

%% Save

    EST_S=EST_W;
    
    disp({i,'/',n})    
    
end
    disp('Est_Shape : done')
end