%% MorphEst Example - This example is a walkthrough explaining how the functions 
% in the MorphEst toolbox. A 'readme' .docx file is also provided to
% explain the inputs and individual steps.


%% Clear workspace
clear
clc
close all

%% 1. Define input directories for 1985
% Load the data to analyze 
A1=dir('D:\*_coords1.txt');
A2=dir('D:\*_r85.txt');
A3=dir('D:\*proj_coords.txt');

%% 1.1. Compute centerline for 1985

EST_C1=centerline_from_mask_MorphEst(A1,A2,A3);

%% Plot channel mask and centerline

imshow(EST_C1.data);
hold on
plot(EST_C1.cl(:,1), EST_C1.cl(:,2), 'r-', 'Linewidth', 2)
scatter(EST_C1.point_x, EST_C1.point_y,  100, 'c', 'filled')
hold off

%% 1.2. Compute bank lines for 1985

EST_B1=banklines_from_mask_MorphEst(EST_C1);

%% Plot channel mask and bank lines

imshow(EST_B1.data);
hold on
plot(EST_B1.bank{1,1}(:,1), EST_B1.bank{1,1}(:,2), 'b-', 'Linewidth', 2)
plot(EST_B1.bank{1,2}(:,1), EST_B1.bank{1,2}(:,2), 'b-', 'Linewidth', 2)
scatter(EST_B1.point_x, EST_B1.point_y,  100, 'c', 'filled')
hold off

%% 1.3. Compute along-channel width for 1985

EST_W1=width_from_mask_MorphEst(EST_B1);

%% 1.4. Compute estuarine shape for 1985

EST_S1=Est_Shape(EST_W1);
EST_S1.S %Display shape

%% Plot along-channel width/length profile

A = movmean(EST_S1.Wbl, 10);

figure(1)
line(EST_S1.Length, EST_S1.Wbl, 'Color', [.5 .5 .5], 'LineWidth', 2)
hold on
line(EST_S1.Length, A, 'Color', 'k', 'LineWidth', 3)

fo = fitoptions('Method','NonlinearLeastSquares','StartPoint',[2300,1400]);
fun = fittype('W*exp(-(x/L))','options',fo);
  
a1=EST_S1.Length(EST_S1.Rind);
a2=EST_S1.Wbl(EST_S1.Rind);
ind=~isnan(a1) & ~isnan(a2);
a3=a1(ind);
a4=a2(ind);
[f,g,~]=fit(a3,a4,fun);

p =  plot(f, 'r--')
p.LineWidth = 2;
hold off

xlim([0 max(EST_S1.Length)])
ylim([0 5000])
xlabel('Length (m)')
ylabel('Width (m)')

set(gca, 'Fontsize', 15)

box on


%% 2. Define input directories for 2015
% Load the data to analyze 
A1=dir('D:\*_coords1.txt');
A2=dir('D:\*_r15.txt');
A3=dir('D:\*proj_coords.txt');

%% 2.1. Compute centerline for 2015

EST_C2=centerline_from_mask_MorphEst(A1,A2,A3);

%% Plot channel mask and centerline

imshow(EST_C2.data);
hold on
plot(EST_C2.cl(:,1), EST_C2.cl(:,2), 'r-', 'LineWidth', 2)
scatter(EST_C2.point_x, EST_C2.point_y,  100, 'c', 'filled')
hold off

%% 2.2. Compute bank lines for 2015

EST_B2=banklines_from_mask_MorphEst(EST_C2);

%% Plot channel mask and bank lines

imshow(EST_B2.data);
hold on
plot(EST_B2.bank{1,1}(:,1), EST_B2.bank{1,1}(:,2), 'b-', 'LineWidth', 2)
plot(EST_B2.bank{1,2}(:,1), EST_B2.bank{1,2}(:,2), 'b-', 'LineWidth', 2)
scatter(EST_B2.point_x, EST_B2.point_y,  100, 'c', 'filled')
hold off

%% 2.3. Compute along-channel width for 2015

EST_W2=width_from_mask_MorphEst(EST_B2);

%% 2.4. Compute estuarine shape for 2015

EST_S2=Est_Shape(EST_W2);
EST_S2.S %Display shape

%% Plot along-channel width/length profile

A = movmean(EST_S2.Wbl, 10);

figure(1)
line(EST_S2.Length, EST_S2.Wbl, 'Color', [.5 .5 .5], 'LineWidth', 2)
hold on
line(EST_S2.Length, A, 'Color', 'k', 'LineWidth', 3)

fo = fitoptions('Method','NonlinearLeastSquares','StartPoint',[2300,1400]);
fun = fittype('W*exp(-(x/L))','options',fo);
  
a1=EST_S2.Length(EST_S2.Rind);
a2=EST_S2.Wbl(EST_S2.Rind);
ind=~isnan(a1) & ~isnan(a2);
a3=a1(ind);
a4=a2(ind);
[f,g,~]=fit(a3,a4,fun);

p =  plot(f, 'r--')
p.LineWidth = 2;
hold off

xlim([0 max(EST_S2.Length)])
ylim([0 5000])
xlabel('Length (m)')
ylabel('Width (m)')

set(gca, 'Fontsize', 15)

box on


%% 3.1. Calculate estuarine length for 1985 and 2015

[EST_SL1,EST_SL2,EST_L]=Est_Length(EST_C1,EST_C2);

%% 3.2. Calculate area change between 1985 and 2015 (also applicable for rivers)

[EST_SA1, EST_SA2, EST_A]=Est_AreaChange(EST_SL1, EST_SL2, EST_L);

%% Plot area change

a=0*ones([size(EST_A.F),3]);
ind1=EST_A.F==1; %Area Loss
ind2=EST_A.F==-3; %Area Gain
ind3=find(EST_A.F==-2); %No Change

%Determine colors
a(:,:,1)=ind1;
a(:,:,2)=ind2;
a1=a(:,:,1); a2=a(:,:,2); a3=a(:,:,3); 
a1(ind3)=1; a2(ind3)=1; a3(ind3)=1;
a=cat(3,a1,a2,a3);

imshow(a)


%% 3.3. Calculate cause of surface area loss  (also applicable for rivers)

[EST_AL]=Est_AreaChange_Land(EST_SA1, EST_SA2, EST_A);